@@ -268,14 +268,23 @@ def after_install(options, home_dir):
     print "Installing Trac software."
     argument = 'trac==0.12.2'
     subprocess.call([join('bin', 'pip'), 'install', argument], cwd=home_dir)
+
     print "Installing Trac-Git software."
     if sys.version_info[:2] >= (2, 5):
         argument = 'http://trac-hacks.org/svn/gitplugin/0.12/'
         subprocess.call([join('bin', 'pip'), 'install', argument], cwd=home_dir)
     else:
         print "Not installing Trac-Git software. It doesn't work with Python 2.4."
+
     print "Installing Trac-Mercurial software."
-    argument = 'http://svn.edgewall.org/repos/trac/plugins/0.12/mercurial-plugin/'
+    mercurial_archive_path = 'https://hg.edgewall.org/trac/mercurial-plugin#0.12'
+    print "Cloning %s" % mercurial_archive_path
+    call_subprocess(['hg', 'clone', mercurial_archive_path], show_stdout=False, cwd=home_dir)
+    print "Running setup.py..."
+    subprocess.call([join('..', 'bin', 'python'), 'setup.py', 'install'], cwd=join(home_dir, 'mercurial-plugin'))
+
+    print "Installing Mercurial software."
+    argument = 'mercurial'
     subprocess.call([join('bin', 'pip'), 'install', argument], cwd=home_dir)
 
     # Get path locations.
